package websocket

import (
	"encoding/json"
	"github.com/gorilla/websocket"

	GoTomato "git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

// Sends a message to the clients websocket
func sendClientCommand(c *Client, msg GoTomato.ClientCommand) {
	if !c.Connected() {
		// noop if client is not connected
		return
	}
	messageBytes, err := json.Marshal(msg)
	if err != nil {
		c.LastErr = err
		return
	}

	err = c.Conn.WriteMessage(websocket.TextMessage, messageBytes)
	if err != nil {
		c.LastErr = err
		return
	}
}

// Sends the passed command to the server
func (c *Client) SendCmd(cmd string) {
	message := GoTomato.ClientCommand{
		Command:  cmd,
		Password: c.Password,
	}

	sendClientCommand(c, message)
}

// Sends the new PomodoroConfig to the server
func (c *Client) SendSettingsUpdate(settings GoTomato.PomodoroConfig) {
	message := GoTomato.ClientCommand{
		Command:  "updateSettings",
		Password: c.Password,
		Settings: settings,
	}

	sendClientCommand(c, message)
}
